package com.logicbig.example;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Component;
import java.util.Arrays;
import java.util.List;

@Component
public class ExampleClient {

    @Autowired
    private EmployeeRepository repo;

    public void run() {
        List<Employee> employees = createEmployees();
        repo.saveAll(employees);

        System.out.println(" -- finding all employees --");
        Iterable<Employee> all = repo.findAll();
        all.forEach(System.out::println);

        System.out.println(" -- paginating where dept is Sales --");
        long count = repo.count();
        int pageSize = 2;
        long pages = count / pageSize;
        for (int i = 0; i < pages; i++) {
            System.out.printf("page num: %s%n", i);
            List<Employee> list = repo.findByDept("Sales", PageRequest.of(i, pageSize));
            list.forEach(System.out::println);
        }

        System.out.println(" -- paginating with sorting by salaries` where dept is Sales --");
        for (int i = 0; i < pages; i++) {
            System.out.printf("page num: %s%n", i);
            List<Employee> list = repo.findByDept("Sales",
                    PageRequest.of(i, pageSize, Sort.by("salary").descending()));
            list.forEach(System.out::println);
        }
    }

    private List<Employee> createEmployees() {
        return Arrays.asList(
                Employee.create("Diana", "Sales", 2000),
                Employee.create("Mike", "Sales", 1000),
                Employee.create("Rose", "IT", 4000),
                Employee.create("Sara", "Sales", 3000),
                Employee.create("Andy", "Sales", 3000),
                Employee.create("Charlie", "Sales", 2500),
                Employee.create("Jim", "Sales", 4500),
                Employee.create("Sam", "Sales", 2500)
        );
    }
}